SnackBarPosition enum

Defines the position where the snackbar will appear on the screen.

Used to control whether the snackbar slides in from the top or bottom of the screen.

Inheritance
Available extensions

Values

top → const SnackBarPosition

Snackbar appears at the top of the screen

bottom → const SnackBarPosition

Snackbar appears at the bottom of the screen

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SnackBarPosition>
A constant List of the values in this enum, in order of their declaration.